DeviceFileSource class final

Inheritance

Constructors

DeviceFileSource(String path)
Provides the device file for the splash screen

Properties

file ↔ File
latefinal
hashCode → int
The hash code for this object.
no setterinherited
path → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setSource() → Future<void>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited