SplashMaster class

Inheritance

Constructors

SplashMaster.lottie({Key? key, Widget? nextScreen, required Source source, VoidCallback? customNavigation, LottieConfig? lottieConfig, VoidCallback? onSourceLoaded, Color? backGroundColor})
Set lottie as splash screen
const
SplashMaster.rive({Key? key, Widget? nextScreen, required Source source, VoidCallback? customNavigation, RiveConfig? riveConfig, VoidCallback? onSourceLoaded, Color? backGroundColor})
Set rive as splash screen
const
SplashMaster.video({Key? key, Widget? nextScreen, required Source source, VoidCallback? customNavigation, VideoConfig? videoConfig, VoidCallback? onSourceLoaded, Color? backGroundColor})
Set video as splash screen
const

Properties

backGroundColor → Color?
backGroundColor of the screen when video or lottie is being displayed using aspect ratio
final
customNavigation → VoidCallback?
If an app has custom navigation or page transition then use this callback to navigate to nextScreen.
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
lottieConfig → LottieConfig?
A config class for lottie splash. Have default parameters which lottie provides.
final
nextScreen → Widget?
The screen which needs to be navigated after the splash screen.
final
onSourceLoaded → VoidCallback?
A callback when provided source completes initializing.
final
riveConfig → RiveConfig?
A config class for rive splash. Controls how a rive animation will look.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → Source
Source for the media which needs to be shown as splash screen.
final
splashMediaType → SplashMediaType
Type of the media which needs to be used as splash screen.
final
videoConfig → VideoConfig?
A config class for video splash. Controls how a video player preview will look.
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<SplashMaster>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

initialize() → void
Prevents flutter frame to be rendered but framework will still produce frames.
resume() → void
Resumes flutter to start rendering frames.