YamlKeys class
Constructors
- YamlKeys()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
supportedAndroid12AndAboveYamlKeys
↔ List<
String> -
List of supported nested keys under
android_12_and_above.getter/setter pair -
supportedYamlKeys
↔ List<
String> -
List of supported top-level keys under
splash_master.getter/setter pair
Constants
- android12AndAboveKey → const String
- Specifies splash screen setup details for Android 12.
- androidBackgroundGravity → const String
- Specifies the gravity for the background image in Android.
- androidDarkGravityKey → const String
- Specifies the gravity for the Android dark mode splash image.
- androidGravityKey → const String
- Specifies the gravity for splash image in the Android.
- backgroundImage → const String
- Specifies the background image for the splash screen.
- backgroundImageDarkKey → const String
- Specifies the dark mode background image.
- brandingImageDarkKey → const String
- Specifies the dark branding image for Android 12+ dark mode.
- brandingImageKey → const String
- Specifies branding image for the Android 12+
- colorDarkKey → const String
- Specifies the dark mode splash screen color.
- colorKey → const String
- Specifies the color in splash screen.
- imageDarkKey → const String
- Specifies the dark mode splash image.
- imageKey → const String
- Specifies the splash image.
- iosBackgroundContentMode → const String
- Specifies the content mode for the background image in iOS.
- iosContentModeKey → const String
- Specifies the content mode for splash image in the iOS.
- splashMasterKey → const String
-
splashMasterKey is used to specify the
splash_mastersection inpubspec.yaml.