Image class
The DM used for fields that are in contents.json
Constructors
Properties
-
appearances
→ List<
Map< ?String, dynamic> > -
Optional list of appearance descriptors (e.g., dark mode).
Each entry is a map like
{"appearance": "luminosity", "value": "dark"}.final - filename → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- idiom → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scale → String
-
final
Methods
-
copyWith(
{String? idiom, String? filename, String? scale, List< Map< ? appearances}) → ImageString, dynamic> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited