IOSStrings class
IOS Strings Element, attribute keys and values
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- appearanceDark → const String
-
Appearance value for dark mode:
dark - appearanceKey → const String
- Appearance key used in Contents.json for dark mode
- appearanceLuminosity → const String
-
Appearance attribute value:
luminosity - appearanceValueKey → const String
- Appearance value attribute key
- backgroundImage → const String
-
BackgroundImage - backgroundImageDarkSnakeCase → const String
-
background_image_dark - backgroundImageSnakeCase → const String
-
background_image - backgroundImageViewIdValue → const String
-
edQ-YT-iED - blueColorAttr → const String
-
blue - clipsSubviews → const String
-
clipsSubviews - clipsSubviewsValue → const String
-
YES - colorAlphaAttr → const String
-
alpha - colorElement → const String
-
color - colorKeyAttr → const String
-
key - colorKeyAttrVal → const String
-
backgroundColor - constraintsElement → const String
-
constraints - contentMode → const String
-
contentMode - contentModeValue → const String
-
scaleToFill - customColorAttr → const String
-
customColorSpace - customColorAttrVal → const String
-
sRGB - defaultAlphaAttrVal → const String
-
1 - defaultColor → const String
-
#FFFFFF - defaultImageViewId → const String
-
id - defaultImageViewIdValue → const String
-
YRO-k0-Ey4 - defaultViewId → const String
-
Element ID
Ze5-6b-2t3 - documentElement → const String
- Element string
- greenColorAttr → const String
-
green - image → const String
-
image - imageResourceElement → const String
-
imagestoryboard resource element - imageValue → const String
-
LaunchImage - imageViewElement → const String
- ImageView Element and attribute
- iosContentJson → const String
-
Contents.json - iOSContentJsonIdiom → const String
-
universal - launchBackgroundColorAssetName → const String
-
LaunchBackgroundColor - launchBackgroundColorSetDirectory → const String
-
LaunchBackgroundColor.colorset - multipleTouchEnabled → const String
-
multipleTouchEnabled - multipleTouchEnabledValue → const String
-
YES - nameAttr → const String
-
name - opaque → const String
- Attribute
- opaqueValue → const String
-
NO - rectElement → const String
- Rect Element
- rectElementHeightAttr → const String
-
height - rectElementHeightAttrVal → const String
-
1280 - rectElementKeyAttr → const String
- Attributes of rect element
- rectElementKeyAttrValue → const String
-
frame - rectElementWidthAttr → const String
-
width - rectElementWidthAttrVal → const String
-
393 - rectElementXAttr → const String
-
x - rectElementXAttrVal → const String
-
0.0 - rectElementYAttr → const String
-
y - rectElementYAttrVal → const String
-
0.0 - redColorAttr → const String
-
red - resourcesElement → const String
-
resources - splashImage → const String
-
splash_image - splashImageDark → const String
-
splash_image_dark - storyboardImageResourceHeight → const String
- Default storyboard image resource height metadata.
- storyboardImageResourceWidth → const String
- Default storyboard image resource width metadata.
- subViewsElement → const String
-
subviews - translatesAutoresizingMaskIntoConstraints → const String
-
translatesAutoresizingMaskIntoConstraints - translatesAutoresizingMaskIntoConstraintsVal → const String
-
NO - viewElement → const String
-
view - viewIdAttr → const String
- Attribute and value string for color